
## CATO-CLI - mutation.policy.appTenantRestriction.removeRule:
[Click here](https://api.catonetworks.com/documentation/#mutation-removeRule) for documentation on this operation.

### Usage for mutation.policy.appTenantRestriction.removeRule:

`catocli mutation policy appTenantRestriction removeRule -h`

`catocli mutation policy appTenantRestriction removeRule <json>`

`catocli mutation policy appTenantRestriction removeRule "$(cat < removeRule.json)"`

`catocli mutation policy appTenantRestriction removeRule '{"appTenantRestrictionPolicyMutationInput": {"policyMutationRevisionInput": {"id": {"id": "ID"}}}, "appTenantRestrictionRemoveRuleInput": {"id": {"id": "ID"}}}'`

#### Operation Arguments for mutation.policy.appTenantRestriction.removeRule ####
`accountId` [ID] - (required) N/A 
`appTenantRestrictionPolicyMutationInput` [AppTenantRestrictionPolicyMutationInput] - (optional) N/A 
`appTenantRestrictionRemoveRuleInput` [AppTenantRestrictionRemoveRuleInput] - (required) N/A 
